@@ -333,7 +333,7 @@ def run_main(mode, path_arg, dep_arguments, output_file_or_dir, file_format, url
                 run_prechecker = True
 
             if src_path == "" and url_to_analyze == "":
-                src_path, dep_arguments, url_to_analyze = get_input_mode()
+                src_path, dep_arguments, url_to_analyze = get_input_mode(_executed_path, mode)
 
             if not hide_progressbar:
                 timer = TimerThread()
